#ifndef NT2_INCLUDE_FUNCTIONS_QUADL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_QUADL_HPP_INCLUDED

#include <nt2/integration/include/functions/quadl.hpp>

#endif
